==> nui_mini_program-0.0.33.tar.gz: lib/engine/nui_miniprogram_js_engine.dart <==
import 'dart:convert';
import 'dart:async';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_mini_program/model/nui_miniprogram_module.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_message.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_engine.dart';
import 'package:webview_flutter_plus/webview_flutter_plus.dart';

class NUIMiniProgramJSEngine with NUIMiniProgramJSEngineInterface{
  NUIMiniProgramJSEngine._builder(NUIMiniProgramModule module){
    _module = module;
  }

  static NUIMiniProgramJSEngine from(NUIMiniProgramModule module){
    return NUIMiniProgramJSEngine._builder(module);
  }

  NUIMiniProgramModule _module;
  WebViewPlusController webController;
  static const MODULE = "NUIMiniProgramJSEngine";

  void setWebController(WebViewPlusController webController){
    this.webController = webController;
  }

  JavascriptChannel getJavascriptChannel(String componentName){
    return JavascriptChannel(
      name: componentName,
      onMessageReceived: (JavascriptMessage message) {
        logNUI(MODULE, "Received ($componentName) javascript message: ${message.message}");
        messageReceived(message.message);
      }
    );
  }

  Future<String> evaluateJavascriptToWeb(WebViewPlusController webController, String javascript){
    return webController.webViewController.evaluateJavascript(javascript);
  }

  @override
  Future<bool> sendPlatformCrossEvent(NUIMiniProgramMessage message) async{
    try {
      final encoded = jsonEncode(message);
      logNUI(MODULE, "Sending platform cross event with message : $encoded");
      final jsScript = "window.postMessage(\'$encoded\', \'*\');";
      final result = await evaluateJavascriptToWeb(webController, jsScript);
      return true;
    }catch(e){
      logNUI(MODULE, "Failed to send platform cross event with error : $e");
      return false;
    }
  }

}

==> nui_mini_program-1.0.8.tar.gz: lib/engine/nui_miniprogram_js_engine.dart <==
import 'dart:convert';
import 'dart:async';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_mini_program/model/nui_miniprogram_module.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_message.dart';
import 'package:nui_miniprogram_core/nui_miniprogram_engine.dart';
import 'package:webview_flutter_plus/webview_flutter_plus.dart';

/**
 * Defining the javascript engine for mini-program
 */
class NUIMiniProgramJSEngine with NUIMiniProgramJSEngineInterface{
  NUIMiniProgramJSEngine._builder(NUIMiniProgramModule module){
    _module = module;
  }

  static NUIMiniProgramJSEngine from(NUIMiniProgramModule module){
    return NUIMiniProgramJSEngine._builder(module);
  }

  late NUIMiniProgramModule _module;
  late WebViewPlusController webController;
  static const MODULE = "NUIMiniProgramJSEngine";

  void setWebController(WebViewPlusController webController){
    this.webController = webController;
  }

  JavascriptChannel getJavascriptChannel(String componentName){
    return JavascriptChannel(
      name: componentName,
      onMessageReceived: (JavascriptMessage message) {
        logNUI(MODULE, "Received ($componentName) javascript message: ${message.message}");
        messageReceived(message.message);
      }
    );
  }

  Future<String> evaluateJavascriptToWeb(WebViewPlusController webController, String javascript){
    return webController.webViewController.evaluateJavascript(javascript);
  }

  @override
  Future<bool> sendPlatformCrossEvent(NUIMiniProgramMessage message) async{
    try {
      final encoded = jsonEncode(message);
      logNUI(MODULE, "Sending platform cross event with message : $encoded");
      final jsScript = "window.postMessage(\'$encoded\', \'*\');";
      final result = await evaluateJavascriptToWeb(webController, jsScript);
      return true;
    }catch(e){
      logNUI(MODULE, "Failed to send platform cross event with error : $e");
      return false;
    }
  }

}
